import PageContent from '@/components/PageContent';
import PageTitle from '@/components/PageTitle';
import { MandateType } from '@/pages/TaskManage/constent';
import styles from '@/pages/TaskManage/index.less';
import { IMandateType, IPropTypes } from '@/pages/TaskManage/index.types';
import { getMandateList } from '@/services/TaskManage';
import { RightOutlined } from '@ant-design/icons';
import { connect, useParams, useRequest } from '@umijs/max';
import { List, Spin } from 'antd';
import { BaseOptionType } from 'rc-select/es/Select';
import React, { useEffect, useState } from 'react';
import { useNavigate } from 'umi';

const TaskManage: React.FC<IPropTypes> = (props) => {
  const { mandateList,loading, dispatch } = props;
  const { projectID } = useParams();
  const project_id = Number(projectID === '' ? '0' : projectID);

  const navigate = useNavigate();
  const [mandateCount, setMandateCount] = useState<number[]>([0, 0, 0]);

  useEffect(() => {
    if (mandateList.length == 0) {
      dispatch({
        type: 'mandate/fetchMandateList',
        payload: { project_id, pageSize: 9999 },
      });
    }
  }, []);

  useEffect(() => {
    const typeCount = [];
    for (let i = 0; i < 3; i++) {
      typeCount[i] = mandateList.filter(
        (item: IMandateType) => item.MandateType === i + 1,
      ).length;
    }
    setMandateCount(typeCount);
  }, [mandateList]);

  const goTaskList = (item: number) => {
    navigate(
      `/task-manage/list?project_id=${project_id}&mandateType=${item}`,
    );
  };

  const makeList = (item: BaseOptionType, index: number) => {
    return (
      <List.Item
        className={styles.listItem}
        onClick={() => {
          goTaskList(item.value);
        }}
      >
        <List.Item.Meta title={item.label} />
        <div className={styles.itemCount}>
          <div className={styles.countNumber}>{mandateCount[index]}</div>
          <div>任务数量</div>
        </div>
        <RightOutlined />
      </List.Item>
    );
  };

  return (
    <PageContent>
      <PageTitle>任务管理</PageTitle>
      <Spin spinning={loading}>
        <List
          className={styles.taskList}
          bordered
          itemLayout="horizontal"
          dataSource={MandateType}
          renderItem={makeList}
          pagination={false}
        />
      </Spin>
    </PageContent>
  );
};

export default connect(({ mandate,loading }: any): { mandateList: IMandateType[], loading:boolean } => {
  return {
    mandateList: mandate.mandateList,
    loading: loading.models['mandate']
  };
})(TaskManage);
